============================
Djblets 0.7.29 Release Notes
============================

**Release date**: January 27, 2014


djblets.webapi
==============

* Add requested query parameters in pagination links. (:bug:`3199`)


Contributors
============

* Christian Hammond
* David Trowbridge
